@@ -1062,16 +1062,19 @@ if (c.hasSelection())
 	if (isRegExp)
 	  {
 	  QRegularExpression expr1(o);
-
 	  QStringList texts;
 	  QString rtext1=r;
 	  int pos = 0;
         while (pos != -1)
 	    {
         QRegularExpressionMatch expr1Match=expr1.match(c.selectedText(),pos);
-	    texts << expr1Match.captured(1);
-        pos=expr1Match.capturedStart();
-	    pos += expr1Match.capturedLength(1);
+        if (expr1Match.hasMatch())
+            {
+            texts << expr1Match.captured(0);
+            pos=expr1Match.capturedStart();
+            pos += expr1Match.capturedLength(0);
+            }
+        else pos=-1;
 	    }
 	  for(int i = 0; i < 10 && i < texts.count(); i++)
 	    {
@@ -1863,10 +1866,14 @@ else
             while (index != -1)
 			{
             QRegularExpressionMatch rxMatch=rx.match(code,index);
-			if (rxMatch.captured(1)=="@") code.replace(rxMatch.capturedStart(1),1,QString(QChar(0x2022)));
-			else if (rxMatch.captured(1)=="@@") code.replace(rxMatch.capturedStart(1),2,"@");
-            index=rxMatch.capturedStart(1);
-			index += rxMatch.capturedLength(1);
+                if (rxMatch.hasMatch())
+                {
+                if (rxMatch.captured(0)=="@") code.replace(rxMatch.capturedStart(0),1,QString(QChar(0x2022)));
+                else if (rxMatch.captured(0)=="@@") code.replace(rxMatch.capturedStart(0),2,"@");
+                index=rxMatch.capturedStart(0);
+                index += rxMatch.capturedLength(0);
+                }
+            else index=-1;
 			}
 		      //code.replace("@",QString(QChar(0x2022)));
 		      if (code.left(1)=="%")
