@@ -1,12 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "lightlinenumberwidget.h"
@@ -92,16 +93,24 @@ while ( p.isValid())
 		  {
 		  if (m_editor->UserBookmark[j]==i) 
 			  {
-			  
-			  painter.fillRect(2, top,fm.width("0")+6,fm.lineSpacing(), bookmarkbrush);	  
+              #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+			  painter.fillRect(2, top,fm.width("0")+6,fm.lineSpacing(), bookmarkbrush);
+              #else
+              painter.fillRect(2, top,fm.horizontalAdvance("0")+6,fm.lineSpacing(), bookmarkbrush);
+              #endif
 			  painter.setPen(bookmarkpen);
 			  painter.drawText(4,top,width()-4,fm.lineSpacing(),Qt::AlignLeft | Qt::AlignTop,QString::number(j+1));
 			  }
 		  }
 	painter.setPen(oldpen);
 	numtext=QString::number(i);
+    #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 	if (p.isVisible()) painter.drawText(10+fm.width("0"), top,fm.width(numtext),fm.lineSpacing(),Qt::AlignRight | Qt::AlignTop,numtext);
-	l= fm.width(numtext)+8+fm.width("0");
+    l= fm.width(numtext)+8+fm.width("0");
+    #else
+    if (p.isVisible()) painter.drawText(10+fm.horizontalAdvance("0"), top,fm.horizontalAdvance(numtext),fm.lineSpacing(),Qt::AlignRight | Qt::AlignTop,numtext);
+    l= fm.horizontalAdvance(numtext)+8+fm.horizontalAdvance("0");
+    #endif
 	if (l>max) max=l;
 	if (i==start+1)
 	  {
@@ -160,7 +169,11 @@ if (event->type() == QEvent::ToolTip)
   {
   QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
   int p = helpEvent->pos().x();
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
   if (abs(p)>=fm.width("0")+8) 
+#else
+   if (abs(p)>=fm.horizontalAdvance("0")+8)
+#endif
     {
      QToolTip::hideText();
      event->ignore();
