@@ -1,13 +1,14 @@
 /***************************************************************************
- *   copyright       : (C) 2012-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
- *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
+ *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 /*
 
@@ -83,6 +84,7 @@ signals:
     void linkClicked(const QString& url);
     void wantNumWords();
     void wantPngExport(int);
+    void wantCheckGrammar(int);
     void syncpage(int, const QPointF&);
     void wantNumPageWords(int);
     void wantOpenLocation();
@@ -155,6 +157,7 @@ private:
     void jumpToSourceFromPdf();
     void requestNumWords();
     void requestPngExport();
+    void requestCheckGrammar();
     void requestPageWords();
     void requestOpenLocation();
     
