@@ -1,15 +1,17 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "pdfviewerwidget.h"
+#include "cmdparser.h"
 
 #include <QtGui>
 #include <QAction>
@@ -22,12 +24,13 @@
 #include <QTextStream>
 #include <QKeySequence>
 #include <QDesktopServices>
-#include <QTextCodec>
 #include <QProgressDialog>
 #include <QHeaderView>
 #include <QScrollBar>
 #include <QMessageBox>
 #include <QApplication>
+#include <QRegularExpression>
+
 
 #include "geticon.h"
 #include "theme.h"
@@ -149,11 +152,11 @@ twoPagesModeAction->setChecked(false);
 viewMenu->addAction(twoPagesModeAction);
   
 rotateLeftAction = new QAction(tr("Rotate left"), this);
-//rotateLeftAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Left));
+//rotateLeftAction->setShortcut(QKeySequence(Qt::CTRL  | Qt::Key_Left));
 viewMenu->addAction(rotateLeftAction);
   
 rotateRightAction = new QAction(tr("Rotate right"), this);
-//rotateRightAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Right));
+//rotateRightAction->setShortcut(QKeySequence(Qt::CTRL  | Qt::Key_Right));
 viewMenu->addAction(rotateRightAction);
 
 presentationAction = new QAction(tr("Presentation..."), this);
@@ -168,7 +171,7 @@ scaleComboBox = new QComboBox(centralToolBarBis);
 zoomCustom = new QLineEdit();
 
 //QValidator *validatorZoom = new QIntValidator(25, 400, this);
-QValidator *validatorZoom = new QRegExpValidator(QRegExp("\\d{0,3}%?"), this);
+QValidator *validatorZoom = new QRegularExpressionValidator(QRegularExpression("\\d{0,3}%?"), this);
 zoomCustom->setValidator(validatorZoom);
 scaleComboBox->setInsertPolicy(QComboBox::NoInsert);
 scalePercents << "25%" << "50%" << "75%" << "100%" << "125%" << "150%" << "200%" << "300%" << "400%";
@@ -226,13 +229,13 @@ pdfview=new DocumentView(centralFrame);
 
 CentralLayout= new QHBoxLayout(centralFrame);
 CentralLayout->setSpacing(0);
-CentralLayout->setMargin(0);
+CentralLayout->setContentsMargins(0,0,0,0);
 CentralLayout->addWidget(listpagesWidget);
 CentralLayout->addWidget(pdfview);
 
 CentralLayoutBis= new QVBoxLayout(centralFrameBis);
 CentralLayoutBis->setSpacing(0);
-CentralLayoutBis->setMargin(0);
+CentralLayoutBis->setContentsMargins(0,0,0,0);
 CentralLayoutBis->addWidget(centralToolBarBis);
 CentralLayoutBis->addWidget(centralFrame);
 
@@ -258,7 +261,7 @@ splitter->addWidget(centralFrameBis);
 splitter->addWidget(StructureTreeView);
 QVBoxLayout *mainlayout= new QVBoxLayout(this);
 mainlayout->setSpacing(0);
-mainlayout->setMargin(0);
+mainlayout->setContentsMargins(0,0,0,0);
 mainlayout->addWidget(splitter);
 QList<int> sizes;
 sizes << 200 << height()-200;
@@ -300,8 +303,11 @@ showingStructure=false;
 StructureTreeView->hide();
 QFont deft=QFont("DejaVu Sans Condensed",qApp->font().pointSize());
 QFontMetrics fm(deft);
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 listpagesWidget->setFixedWidth(30+fm.width(QString::number(100)));  
+#else
+listpagesWidget->setFixedWidth(30+fm.horizontalAdvance(QString::number(100)));
+#endif
 path= QPainterPath();
 altern=1;
 currentScale=1;
@@ -359,6 +365,7 @@ if (pdfview->open(fn))
     else 
       {
       zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
+      pdfview->setScaleMode(DocumentView::ScaleFactor);
       pdfview->setScaleFactor(currentScale);
       }
     }
@@ -370,7 +377,11 @@ if (pdfview->open(fn))
     currentScale=pdfview->realScale();
     zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
     }
+    #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
   listpagesWidget->setFixedWidth(30+fm.width(QString::number(pdfview->doc()->pageCount())));
+#else
+  listpagesWidget->setFixedWidth(30+fm.horizontalAdvance(QString::number(pdfview->doc()->pageCount())));
+#endif
   for (int i = 0; i < pdfview->doc()->pageCount(); ++i)
     {
     QListWidgetItem *item=new QListWidgetItem(QString::number(i+1));
@@ -424,7 +435,7 @@ connect(fitPageAct, SIGNAL(triggered()), this, SLOT(fitPage()));
 connect(zoominAct, SIGNAL(triggered()), this, SLOT(zoomIn()));
 connect(zoomoutAct, SIGNAL(triggered()), this, SLOT(zoomOut()));
 connect(zoomCustom, SIGNAL(returnPressed()),this, SLOT(userZoom()));
-connect(scaleComboBox, SIGNAL(currentIndexChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
+connect(scaleComboBox, SIGNAL(currentTextChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
 connect(searchLineEdit, SIGNAL(returnPressed()), this, SLOT(searchDocument()));
 connect(searchAct, SIGNAL(triggered()), this, SLOT(searchDocument()));
 //connect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
@@ -440,6 +451,7 @@ connect(pdfview, SIGNAL(requestZoomOut()), this, SLOT(zoomOut()));
 connect(pdfview, SIGNAL(continousModeChanged(bool)), this,SLOT(on_currentTab_continuousModeChanged(bool)));
 connect(pdfview, SIGNAL(twoPagesModeChanged(bool)), this,SLOT(on_currentTab_twoPagesModeChanged(bool)));
 connect(pdfview,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
+connect(pdfview, SIGNAL(scaleFactorChanged(qreal)), this, SLOT(scaleModified()));
 connect(continuousModeAction, SIGNAL(triggered(bool)),this, SLOT(on_continuousMode_triggered(bool)));
 connect(twoPagesModeAction, SIGNAL(triggered(bool)),this, SLOT(on_twoPagesMode_triggered(bool)));
 connect(rotateLeftAction, SIGNAL(triggered()), this,SLOT(on_rotateLeft_triggered()));
@@ -462,7 +474,7 @@ disconnect(fitPageAct, SIGNAL(triggered()), this, SLOT(fitPage()));
 disconnect(zoominAct, SIGNAL(triggered()), this, SLOT(zoomIn()));
 disconnect(zoomoutAct, SIGNAL(triggered()), this, SLOT(zoomOut()));
 disconnect(zoomCustom, SIGNAL(returnPressed()),this, SLOT(userZoom()));
-disconnect(scaleComboBox, SIGNAL(currentIndexChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
+disconnect(scaleComboBox, SIGNAL(currentTextChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
 disconnect(searchLineEdit, SIGNAL(returnPressed()), this, SLOT(searchDocument()));
 disconnect(searchAct, SIGNAL(triggered()), this, SLOT(searchDocument()));
 //disconnect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
@@ -478,6 +490,7 @@ disconnect(pdfview, SIGNAL(requestZoomOut()), this, SLOT(zoomOut()));
 disconnect(pdfview, SIGNAL(continousModeChanged(bool)), this,SLOT(on_currentTab_continuousModeChanged(bool)));
 disconnect(pdfview, SIGNAL(twoPagesModeChanged(bool)), this,SLOT(on_currentTab_twoPagesModeChanged(bool)));
 disconnect(pdfview,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
+disconnect(pdfview, SIGNAL(scaleFactorChanged(qreal)), this, SLOT(scaleModified()));
 disconnect(continuousModeAction, SIGNAL(triggered(bool)), this,SLOT(on_continuousMode_triggered(bool)));
 disconnect(twoPagesModeAction, SIGNAL(triggered(bool)), this,SLOT(on_twoPagesMode_triggered(bool)));
 disconnect(rotateLeftAction, SIGNAL(triggered()), this,SLOT(on_rotateLeft_triggered()));
@@ -502,7 +515,7 @@ if (scanner == NULL)
   }
 const QFileInfo sourceFileInfo(sourceFile);
 QDir curDir(QFileInfo(pdf_file).canonicalPath());
-synctex_node_t node = synctex_scanner_input(scanner);
+synctex_node_p node = synctex_scanner_input(scanner);
 QString name;
 bool found = false;
 while (node != NULL) 
@@ -522,11 +535,11 @@ if (!found)
   return;
   }
 
-if (synctex_display_query(scanner, name.toUtf8().data(), source_line, 0) > 0) 
+if (synctex_display_query(scanner, name.toUtf8().data(), source_line,source_col, 0) > 0)
   {
   int page = -1;
   path= QPainterPath();
-  while ((node = synctex_next_result(scanner)) != NULL) 
+  while ((node = synctex_scanner_next_result(scanner)) != NULL)
     {
     if (page == -1) page = synctex_node_page(node);
     if (synctex_node_page(node) != page) continue;
@@ -630,7 +643,8 @@ if (zoom.toInt() > 0 && zoom.toInt() <= 400)
 //   int newvpos=(int) (s*(pdfview->verticalScrollBar()->value()+pdfview->viewport()->height()/2)-pdfview->viewport()->height()/2);
 
   pdfview->setScaleMode(DocumentView::ScaleFactor);
-  pdfview->setScaleFactor(s*pdfview->scaleFactor());
+  pdfview->setScaleFactor(currentScale);
+//  pdfview->setScaleFactor(s*pdfview->scaleFactor());
   currentScale=pdfview->realScale();
   lastScale=currentScale;
   previousScale=currentScale;
@@ -884,7 +898,9 @@ if (fi.exists())
 	{
 	proc = new QProcess( this );
 	proc->setWorkingDirectory(fi.absolutePath());
-	proc->start(command);
+    const cmdInfo commandInfo=splitCommand(command);
+    proc->start(commandInfo.program,commandInfo.arguments);
+	//proc->start(command);
 	}
 }
 
@@ -952,9 +968,9 @@ pdfview->print(&printer);
       default:
 	      break;
       }
-  switch(printer.orientation()) 
+  switch(printer.pageLayout().orientation())
       {
-      case QPrinter::Landscape:
+      case QPageLayout::Landscape:
 	      args << "-o landscape";
 	      break;
       default:
@@ -984,8 +1000,8 @@ void PdfViewerWidget::jumpToEditor(int page, const QPointF& pos)
 if (scanner == NULL) return;
 if (synctex_edit_query(scanner, page+1, pos.x(), pos.y()) > 0) 
   {
-  synctex_node_t node;
-  while ((node = synctex_next_result(scanner)) != NULL) 
+  synctex_node_p node;
+  while ((node = synctex_scanner_next_result(scanner)) != NULL)
     {
     QString filename = QString::fromUtf8(synctex_scanner_get_name(scanner, synctex_node_tag(node)));
     QDir curDir(QFileInfo(pdf_file).canonicalPath());
@@ -1176,4 +1192,7 @@ void PdfViewerWidget::getFocus()
 pdfview->setFocus();
 }
 
-
+void PdfViewerWidget::scaleModified()
+{
+    emit scaleHasChanged();
+}
