@@ -1,12 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #ifndef PDFVIEWERWIDGET_H
@@ -83,7 +84,7 @@ bool fileLoaded;
 QPointer<QProcess> proc;
 QString lastFile;
 int lastPage, altern;
-synctex_scanner_t scanner;
+synctex_scanner_p scanner;
 QStringList scalePercents;
 QLineEdit *zoomCustom;
 int lastSearchPos;
@@ -138,6 +139,8 @@ void on_presentation_triggered();
 void on_currentTab_continuousModeChanged(bool continuousMode);
 void on_currentTab_twoPagesModeChanged(bool twoPagesMode);
 
+void scaleModified();
+
 protected:
 void keyPressEvent ( QKeyEvent * e );
 
@@ -147,6 +150,7 @@ void sendFocusToEditor();
 void sendPaperSize(const QString&);
 void backwardAvailable(bool);
 void forwardAvailable(bool);
+void scaleHasChanged();
 };
 
 #endif
